float4x4 WorldViewProj : WorldViewProjection;

float4	g_LightDirec:DIRECTION;		//Direction of Light
float4	g_LightDiffuse;
float4	g_LightAmbient;
float4	g_Diffuse : DIFFUSE;	//Diffuse
float4	g_Ambient : AMBIENT;	//Ambient
int g_NumTextures;
texture	g_Texture0;

sampler TextureSampler = sampler_state
{
	Texture = <g_Texture0>;

	MinFilter = LINEAR;
	MagFilter = LINEAR;
	MipFilter = LINEAR;

	AddressU = Wrap;
	AddressV = Wrap;
};

struct VS_OUTPUT
{
	float4 Pos  : POSITION;
	float4 Col  : COLOR0;
	float2 TexUV	: TEXCOORD0;
};

VS_OUTPUT VS(
	  float4 Pos	: POSITION,
	  float3 Normal : NORMAL,
	  float2 TexUV	: TEXCOORD0
){
	VS_OUTPUT Out = (VS_OUTPUT)0;

	Out.Pos = mul(Pos, WorldViewProj);
	Out.TexUV = TexUV;
	float3 light = normalize(g_LightDirec.xyz);
	float3 norm=normalize(Normal);
	//Out.Col = saturate(max( dot(light, Normal), 0) * g_Diffuse*g_LightCol + g_Ambient);
	//Out.Col = max( dot(light, norm), 0) * g_Diffuse + g_Ambient;
	Out.Col = max( dot(light, norm), 0) * g_Diffuse*g_LightDiffuse + g_Ambient*g_LightAmbient;

	return Out;
}

float4 PS(
	float2 TexUV	: TEXCOORD0,
		float4 Col  : COLOR0 ) : COLOR
{
	if(g_NumTextures){
		Col = tex2D( TextureSampler, TexUV ) * Col;
	}

	return Col;
}


technique technique0
{
	pass p0
	{
		VertexShader = compile vs_2_0 VS();
		PixelShader  = compile ps_2_0 PS();
	}
}

